==> arraylake-0.14.0.tar.gz: arraylake-0.14.0/tests/icechunk/test_storage.py <==
from typing import Callable

import icechunk
import pytest

from arraylake.repos.icechunk.storage import (
    ICECHUNK_REQUIRED_ENV_VARS,
    CredentialType,
    _get_credential_type,
    _get_icechunk_storage_obj,
)
from arraylake.types import DBID, BucketResponse, S3Credentials

repo_id = DBID(b"some_repo_id")


def test_get_credential_type(s3_credentials: S3Credentials, credential_refresh_func: Callable):
    assert _get_credential_type(s3_credentials, None) == CredentialType.PROVIDED
    assert _get_credential_type(None, credential_refresh_func) == CredentialType.PROVIDED
    assert _get_credential_type(None, None) == CredentialType.ENV


def test_get_icechunk_storage_obj_s3_credentials(
    s3_bucket_config: BucketResponse,
    s3_credentials: S3Credentials,
):
    storage = _get_icechunk_storage_obj(
        bucket_config=s3_bucket_config,
        prefix=None,
        s3_credentials=s3_credentials,
        credential_type=CredentialType.PROVIDED,
        credential_refresh_func=None,
    )
    assert isinstance(storage, icechunk.Storage)


def test_get_icechunk_storage_obj_from_env(s3_bucket_config: BucketResponse, monkeypatch):
    for var in ICECHUNK_REQUIRED_ENV_VARS:
        monkeypatch.setenv(var, "test")

    storage = _get_icechunk_storage_obj(
        bucket_config=s3_bucket_config, prefix=None, s3_credentials=None, credential_type=CredentialType.ENV, credential_refresh_func=None
    )
    assert isinstance(storage, icechunk.Storage)

    # Remove environment variables
    for var in ICECHUNK_REQUIRED_ENV_VARS:
        monkeypatch.delenv(var)


def test_get_icechunk_storage_obj_no_credentials(s3_bucket_config: BucketResponse):
    storage = _get_icechunk_storage_obj(
        bucket_config=s3_bucket_config,
        prefix=None,
        s3_credentials=None,
        credential_type=CredentialType.ANONYMOUS,
        credential_refresh_func=None,
    )
    assert isinstance(storage, icechunk.Storage)


def test_get_icechunk_storage_obj_gcs(gcs_bucket_config: BucketResponse):
    storage = _get_icechunk_storage_obj(
        bucket_config=gcs_bucket_config, prefix=None, s3_credentials=None, credential_type=CredentialType.ENV, credential_refresh_func=None
    )
    assert isinstance(storage, icechunk.Storage)


def test_get_icechunk_storage_obj_invalid_credential_input(
    s3_bucket_config: BucketResponse, s3_credentials: S3Credentials, credential_refresh_func: Callable
):
    with pytest.raises(ValueError) as e:
        _get_icechunk_storage_obj(
            bucket_config=s3_bucket_config,
            prefix=None,
            s3_credentials=s3_credentials,
            credential_type=CredentialType.PROVIDED,
            credential_refresh_func=credential_refresh_func,
        )
    assert "Cannot provide both static credentials and a credential refresh function" in str(e.value)

==> arraylake-0.15.1.tar.gz: arraylake-0.15.1/tests/icechunk/test_storage.py <==
from typing import Callable

import icechunk
import pytest

from arraylake.repos.icechunk.storage import (
    ICECHUNK_REQUIRED_ENV_VARS,
    CredentialType,
    _get_credential_type,
    _get_icechunk_storage_obj,
)
from arraylake.types import DBID, BucketResponse, GSCredentials, S3Credentials

repo_id = DBID(b"some_repo_id")


def test_get_credential_type(s3_credentials: S3Credentials, gs_credentials: GSCredentials, credential_refresh_func: Callable):
    assert _get_credential_type(s3_credentials, None) == CredentialType.PROVIDED
    assert _get_credential_type(gs_credentials, None) == CredentialType.PROVIDED
    assert _get_credential_type(None, credential_refresh_func) == CredentialType.PROVIDED
    assert _get_credential_type(None, None) == CredentialType.ENV


def test_get_icechunk_storage_obj_s3_credentials(
    s3_bucket_config: BucketResponse,
    s3_credentials: S3Credentials,
):
    storage = _get_icechunk_storage_obj(
        bucket_config=s3_bucket_config,
        prefix=None,
        credentials=s3_credentials,
        credential_type=CredentialType.PROVIDED,
        credential_refresh_func=None,
    )
    assert isinstance(storage, icechunk.Storage)


def test_get_icechunk_storage_obj_gcs_credentials(
    gcs_bucket_config: BucketResponse,
    gs_credentials: GSCredentials,
):
    storage = _get_icechunk_storage_obj(
        bucket_config=gcs_bucket_config,
        prefix=None,
        credentials=gs_credentials,
        credential_type=CredentialType.PROVIDED,
        credential_refresh_func=None,
    )
    assert isinstance(storage, icechunk.Storage)


def test_get_icechunk_storage_obj_from_env(s3_bucket_config: BucketResponse, monkeypatch):
    for var in ICECHUNK_REQUIRED_ENV_VARS:
        monkeypatch.setenv(var, "test")

    storage = _get_icechunk_storage_obj(
        bucket_config=s3_bucket_config, prefix=None, credentials=None, credential_type=CredentialType.ENV, credential_refresh_func=None
    )
    assert isinstance(storage, icechunk.Storage)

    # Remove environment variables
    for var in ICECHUNK_REQUIRED_ENV_VARS:
        monkeypatch.delenv(var)


def test_get_icechunk_storage_obj_s3_no_credentials(s3_bucket_config: BucketResponse):
    storage = _get_icechunk_storage_obj(
        bucket_config=s3_bucket_config,
        prefix=None,
        credentials=None,
        credential_type=CredentialType.ANONYMOUS,
        credential_refresh_func=None,
    )
    assert isinstance(storage, icechunk.Storage)


def test_get_icechunk_storage_obj_gcs_no_credentials(gcs_bucket_config: BucketResponse):
    storage = _get_icechunk_storage_obj(
        bucket_config=gcs_bucket_config, prefix=None, credentials=None, credential_type=CredentialType.ENV, credential_refresh_func=None
    )
    assert isinstance(storage, icechunk.Storage)


def test_get_icechunk_storage_obj_invalid_credential_input(
    s3_bucket_config: BucketResponse, s3_credentials: S3Credentials, credential_refresh_func: Callable
):
    with pytest.raises(ValueError) as e:
        _get_icechunk_storage_obj(
            bucket_config=s3_bucket_config,
            prefix=None,
            credentials=s3_credentials,
            credential_type=CredentialType.PROVIDED,
            credential_refresh_func=credential_refresh_func,
        )
    assert "Cannot provide both static credentials and a credential refresh function" in str(e.value)
